@@ -77,8 +77,8 @@ class DAO():
         self.logger.debug('DAO.add_an_account')
         self.logger.debug(account)
         sql = """
-        INSERT INTO account ("website", "nickname", "username", "password")
-          VALUES (:website,:nickname,:username,:password)
+        INSERT INTO account ("website", "nickname", "username", "password", "auto_update")
+          VALUES (:website,:nickname,:username,:password, :auto_update)
         """
         con = self.get_connection()
         c = con.cursor()
@@ -95,7 +95,7 @@ class DAO():
         self.logger.debug(account)
         
         sql = """
-        UPDATE account SET website=:website,nickname=:nickname,username=:username,password=:password,
+        UPDATE account SET website=:website,nickname=:nickname,username=:username,password=:password,auto_update=:auto_update,
         last_update_time_friends=:last_update_time_friends,
         last_update_time_mentions=:last_update_time_mentions,
         last_update_time_comments=:last_update_time_comments,
@@ -380,12 +380,12 @@ class DAO():
     def save_settings(self,settings):
         con = self.get_connection()
         c = con.cursor()
-        
+
         c.execute("DELETE FROM settings")
         #print c.rowcount
         sql = """
-            INSERT INTO settings ("downpic", "updatenum")
-              VALUES (:downpic,:updatenum)
+            INSERT INTO settings ("downpic", "updatenum", "background", "updateinterval", "notify_led", "notify_vibra", "notify_sound", "updateinterval2", "down_orgpic", "auto_conn")
+              VALUES (:downpic,:updatenum, :background, :updateinterval, :notify_led, :notify_vibra, :notify_sound, :updateinterval2, :down_orgpic, :auto_conn)
             """
             
         c.execute(sql, settings)
