@@ -19,7 +19,7 @@ APP_KEY="475214689"
 APP_SECRET="f9b9d4850089e3b95a5c3e6e1d17bed5"
 
 class UpdaterSina(QThread):
-    def __init__(self,callback,parent=None):
+    def __init__(self,callback,parent=None, accountId=None):
         super(UpdaterSina, self).__init__(parent)
         self.logger = logging.getLogger('UpdaterSina')
         self.stopped = False
@@ -30,6 +30,7 @@ class UpdaterSina(QThread):
         self.downloader = Downloader()
         self.callback=callback
         self.logger.debug("UpdaterSina:__init__")
+        self.accountId=accountId
 
     def basicAuth(self, source, username, password):
         self.auth = BasicAuthHandler(username, password)
@@ -47,7 +48,7 @@ class UpdaterSina(QThread):
         self.auth.setToken(username, password)
         self.api = API(self.auth)
 
-    def initialize(self, accountId,timelineType,sinceId=None,maxId=None,countnum=20,downpic=False):
+    def initialize(self, accountId,timelineType,sinceId=None,maxId=None,countnum=20,downpic=False, optype = None):
         self.logger.debug("UpdaterSina:initialize")
         self.stopped = False
         self.accountId=accountId
@@ -59,7 +60,8 @@ class UpdaterSina(QThread):
         self.completed = False
         self.timeline = []
         self.userinfo = []
-
+        self.unread_counts = {}
+        self.optype = optype # for clear unread counts
 
     def stop(self):
         try:
@@ -88,6 +90,7 @@ class UpdaterSina(QThread):
 
 
     def update_timeline(self,sinceId=None,maxId=None,countNum=20,pageNum=1):
+        #print "update_timeline"
         self.logger.debug("update_timeline")
         param={}
         param["count"]=countNum
@@ -115,11 +118,23 @@ class UpdaterSina(QThread):
             param["source"]=APP_KEY
             param["id"]=1863105202
             timeline = self.api.favorites(**param)
+        elif self.timelineType==Utils.TIMELINE_TYPE_UNREAD:
+            param={}
+            param["with_new_status"]=0
+            timeline = self.api.unread(**param)
+        elif self.timelineType==Utils.TIMELINE_TYPE_DEUNREAD:
+            param={}
+            #print "update_timeline, optype", self.optype
+            if self.optype == Utils.TIMELINE_TYPE_MENTIONS:
+                param["type"]=2
+            elif self.optype == Utils.TIMELINE_TYPE_COMMENTS:    
+                param["type"]=1
+            timeline = self.api.reset_count(**param)
 
         #print str(time.time()) + ": " + "After updater update_timeline"
 
         counts = None
-        if timeline!=None:
+        if self.timelineType != Utils.TIMELINE_TYPE_UNREAD and self.timelineType != Utils.TIMELINE_TYPE_DEUNREAD and timeline!=None:
             param_id = {}
             param_id["ids"]=""
             tmp_flag = 0
@@ -170,6 +185,8 @@ class UpdaterSina(QThread):
                                 picSource=self.downloader.download(rtThumbnail)
                                 self.writer.write_to(picFilename, picSource)
                 #print str(time.time()) + ": " + "After downloading images"
+        elif self.timelineType == Utils.TIMELINE_TYPE_UNREAD:  
+            self.unread_counts = Utils.build_a_unread_count_from_obj(timeline)
         
         if self.timelineType==Utils.TIMELINE_TYPE_FRIENDS and param_id["ids"]!="": 
             counts = self.api.counts(**param_id)
@@ -185,9 +202,11 @@ class UpdaterSina(QThread):
         #print str(time.time()) + ": After build_a_status"
 
         self.completed = True
-        if self.timelineType!=Utils.TIMELINE_TYPE_ST_COMMENTS:   
+        if self.timelineType==Utils.TIMELINE_TYPE_UNREAD:
+            self.emit(SIGNAL("unread_finished(int)"),self.accountId)
+        elif self.timelineType!=Utils.TIMELINE_TYPE_ST_COMMENTS and self.timelineType!=Utils.TIMELINE_TYPE_DEUNREAD:   
             self.emit(SIGNAL("finished(bool)"),self.completed)
-        else:
+        elif self.timelineType == Utils.TIMELINE_TYPE_ST_COMMENTS:
             self.emit(SIGNAL("cm_finished(bool)"),self.completed)
         self.logger.info("update completed!")
 
@@ -267,6 +286,7 @@ class SenderSina(QThread):
                 self.logger.debug(ae)
                 self.logger.debug("just a text msg")
                 status=self.api.update_status(**param)
+                
         elif timelineType==Utils.TIMELINE_TYPE_MENTIONS:
             self.logger.debug("send a rt")
             #rt
@@ -282,7 +302,7 @@ class SenderSina(QThread):
                     param1["status"]=param["comment"]
                     #print  " param1[status]" + param1["status"] + " id : " + str( param1["id"])
                     param["without_mention"]=0
-                    print "id" + str(param1["id"]) + "   cid" + str(param["cid"])
+                    #print "id" + str(param1["id"]) + "   cid" + str(param["cid"])
                     status=self.api.repost(**param1)
                 #print  " param[comment]" + param["comment"] + " id : " + str( param["id"])
                 status=self.api.comment(**param)
